# Copyright (c) 2012 Cloudera, Inc. All rights reserved.

from cmf.monitor.jmx_beans import JsonParserJmx

class JsonParser(JsonParserJmx):
  def __init__(self, json_dict):
    """
    May raise ParseError if the json structure is not what we expect.
    """
    JsonParserJmx.__init__(self, json_dict, 'DATANODE')

# Collected from bolt CDH4 DN on 10/18/2012.
SAMPLE = r"""
{
  "beans" : [ {
    "name" : "java.lang:type=MemoryPool,name=PS Eden Space",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Eden Space",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 114098176,
      "init" : 197722112,
      "max" : 355008512,
      "used" : 0
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep", "PS Scavenge" ],
    "PeakUsage" : {
      "committed" : 262340608,
      "init" : 197722112,
      "max" : 357367808,
      "used" : 262340608
    },
    "Usage" : {
      "committed" : 114098176,
      "init" : 197722112,
      "max" : 355008512,
      "used" : 6974640
    },
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdSupported" : false
  }, {
    "name" : "java.lang:type=Memory",
    "modelerType" : "sun.management.MemoryImpl",
    "Verbose" : false,
    "HeapMemoryUsage" : {
      "committed" : 180879360,
      "init" : 790667136,
      "max" : 954466304,
      "used" : 53561744
    },
    "NonHeapMemoryUsage" : {
      "committed" : 41680896,
      "init" : 24313856,
      "max" : 136314880,
      "used" : 41308224
    },
    "ObjectPendingFinalizationCount" : 0
  }, {
    "name" : "java.lang:type=MemoryPool,name=PS Survivor Space",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Survivor Space",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 1441792,
      "init" : 32899072,
      "max" : 1441792,
      "used" : 1212416
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep", "PS Scavenge" ],
    "PeakUsage" : {
      "committed" : 46858240,
      "init" : 32899072,
      "max" : 46858240,
      "used" : 35271248
    },
    "Usage" : {
      "committed" : 1441792,
      "init" : 32899072,
      "max" : 1441792,
      "used" : 1212416
    },
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdSupported" : false
  }, {
    "name" : "java.lang:type=GarbageCollector,name=PS MarkSweep",
    "modelerType" : "sun.management.GarbageCollectorImpl",
    "LastGcInfo" : {
      "GcThreadCount" : 13,
      "duration" : 173,
      "endTime" : 173719433,
      "id" : 97,
      "memoryUsageAfterGc" : [ {
        "key" : "PS Survivor Space",
        "value" : {
          "committed" : 1441792,
          "init" : 32899072,
          "max" : 1441792,
          "used" : 0
        }
      }, {
        "key" : "PS Old Gen",
        "value" : {
          "committed" : 65339392,
          "init" : 527171584,
          "max" : 715849728,
          "used" : 32831672
        }
      }, {
        "key" : "PS Perm Gen",
        "value" : {
          "committed" : 34209792,
          "init" : 21757952,
          "max" : 85983232,
          "used" : 33860832
        }
      }, {
        "key" : "Code Cache",
        "value" : {
          "committed" : 5177344,
          "init" : 2555904,
          "max" : 50331648,
          "used" : 5080960
        }
      }, {
        "key" : "PS Eden Space",
        "value" : {
          "committed" : 91357184,
          "init" : 197722112,
          "max" : 354942976,
          "used" : 0
        }
      } ],
      "memoryUsageBeforeGc" : [ {
        "key" : "PS Survivor Space",
        "value" : {
          "committed" : 1441792,
          "init" : 32899072,
          "max" : 1441792,
          "used" : 868456
        }
      }, {
        "key" : "PS Old Gen",
        "value" : {
          "committed" : 82575360,
          "init" : 527171584,
          "max" : 715849728,
          "used" : 82393368
        }
      }, {
        "key" : "PS Perm Gen",
        "value" : {
          "committed" : 34209792,
          "init" : 21757952,
          "max" : 85983232,
          "used" : 33860832
        }
      }, {
        "key" : "Code Cache",
        "value" : {
          "committed" : 5177344,
          "init" : 2555904,
          "max" : 50331648,
          "used" : 5080960
        }
      }, {
        "key" : "PS Eden Space",
        "value" : {
          "committed" : 91357184,
          "init" : 197722112,
          "max" : 354942976,
          "used" : 0
        }
      } ],
      "startTime" : 173719260
    },
    "CollectionCount" : 97,
    "CollectionTime" : 17935,
    "Name" : "PS MarkSweep",
    "Valid" : true,
    "MemoryPoolNames" : [ "PS Eden Space", "PS Survivor Space", "PS Old Gen", "PS Perm Gen" ]
  }, {
    "name" : "Hadoop:service=DataNode,name=DataNodeActivity-c0814.hal.cloudera.com-50010",
    "modelerType" : "DataNodeActivity-c0814.hal.cloudera.com-50010",
    "tag.SessionId" : null,
    "tag.Context" : "dfs",
    "tag.Hostname" : "c0814.hal.cloudera.com",
    "BytesWritten" : 870766834750,
    "BytesRead" : 3834690505797,
    "BlocksWritten" : 20027,
    "BlocksRead" : 13562738,
    "BlocksReplicated" : 28,
    "BlocksRemoved" : 20670,
    "BlocksVerified" : 2113,
    "BlockVerificationFailures" : 0,
    "ReadsFromLocalClient" : 13399833,
    "ReadsFromRemoteClient" : 162905,
    "WritesFromLocalClient" : 5900,
    "WritesFromRemoteClient" : 13899,
    "BlocksGetLocalPathInfo" : 0,
    "FsyncCount" : 0,
    "VolumeFailures" : 0,
    "ReadBlockOpNumOps" : 13562738,
    "ReadBlockOpAvgTime" : 0.6225165562913907,
    "WriteBlockOpNumOps" : 19799,
    "WriteBlockOpAvgTime" : 4.0,
    "BlockChecksumOpNumOps" : 0,
    "BlockChecksumOpAvgTime" : 0.0,
    "CopyBlockOpNumOps" : 0,
    "CopyBlockOpAvgTime" : 0.0,
    "ReplaceBlockOpNumOps" : 0,
    "ReplaceBlockOpAvgTime" : 0.0,
    "HeartbeatsNumOps" : 182214,
    "HeartbeatsAvgTime" : 0.33333333333333337,
    "BlockReportsNumOps" : 30,
    "BlockReportsAvgTime" : 53.0,
    "PacketAckRoundTripTimeNanosNumOps" : 44882974,
    "PacketAckRoundTripTimeNanosAvgTime" : 284129.697761194,
    "FlushNanosNumOps" : 69384058,
    "FlushNanosAvgTime" : 6061.629322268328,
    "FsyncNanosNumOps" : 0,
    "FsyncNanosAvgTime" : 0.0,
    "SendDataPacketBlockedOnNetworkNanosNumOps" : 85442941,
    "SendDataPacketBlockedOnNetworkNanosAvgTime" : 9755.48333333333,
    "SendDataPacketTransferNanosNumOps" : 85442941,
    "SendDataPacketTransferNanosAvgTime" : 74358.75555555554
  }, {
    "name" : "Hadoop:service=DataNode,name=FSDatasetState-DS-1777746897-172.29.97.205-50010-1337120462383",
    "modelerType" : "org.apache.hadoop.hdfs.server.datanode.fsdataset.impl.FsDatasetImpl",
    "Remaining" : 1703360933460,
    "StorageInfo" : "FSDataset{dirpath='[/data/1/dfs/dn/current, /data/2/dfs/dn/current, /data/3/dfs/dn/current, /data/4/dfs/dn/current, /data/5/dfs/dn/current, /data/6/dfs/dn/current]'}",
    "Capacity" : 5688127021056,
    "DfsUsed" : 3963318498784,
    "NumFailedVolumes" : 0
  }, {
    "name" : "java.lang:type=Compilation",
    "modelerType" : "sun.management.CompilationImpl",
    "Name" : "HotSpot 64-Bit Tiered Compilers",
    "CompilationTimeMonitoringSupported" : true,
    "TotalCompilationTime" : 26402
  }, {
    "name" : "Hadoop:service=DataNode,name=RpcActivityForPort50020",
    "modelerType" : "RpcActivityForPort50020",
    "tag.port" : "50020",
    "tag.Context" : "rpc",
    "tag.Hostname" : "c0814.hal.cloudera.com",
    "ReceivedBytes" : 7197270,
    "SentBytes" : 199299,
    "RpcQueueTimeNumOps" : 201,
    "RpcQueueTimeAvgTime" : 1.0,
    "RpcProcessingTimeNumOps" : 201,
    "RpcProcessingTimeAvgTime" : 1.0,
    "RpcAuthenticationFailures" : 0,
    "RpcAuthenticationSuccesses" : 0,
    "RpcAuthorizationFailures" : 0,
    "RpcAuthorizationSuccesses" : 157,
    "NumOpenConnections" : 0,
    "CallQueueLength" : 0
  }, {
    "name" : "java.lang:type=OperatingSystem",
    "modelerType" : "com.sun.management.UnixOperatingSystem",
    "MaxFileDescriptorCount" : 32768,
    "OpenFileDescriptorCount" : 223,
    "CommittedVirtualMemorySize" : 1982926848,
    "FreePhysicalMemorySize" : 9439920128,
    "FreeSwapSpaceSize" : 25370288128,
    "ProcessCpuTime" : 27212000000000,
    "TotalPhysicalMemorySize" : 50602696704,
    "TotalSwapSpaceSize" : 25370288128,
    "Name" : "Linux",
    "Version" : "2.6.32-279.el6.x86_64",
    "AvailableProcessors" : 16,
    "Arch" : "amd64",
    "SystemLoadAverage" : 0.52
  }, {
    "name" : "java.lang:type=MemoryManager,name=CodeCacheManager",
    "modelerType" : "sun.management.MemoryManagerImpl",
    "Name" : "CodeCacheManager",
    "Valid" : true,
    "MemoryPoolNames" : [ "Code Cache" ]
  }, {
    "name" : "Hadoop:service=DataNode,name=MetricsSystem,sub=Stats",
    "modelerType" : "MetricsSystem,sub=Stats",
    "tag.Context" : "metricssystem",
    "tag.Hostname" : "c0814.hal.cloudera.com",
    "NumActiveSources" : 5,
    "NumAllSources" : 5,
    "NumActiveSinks" : 0,
    "NumAllSinks" : 0,
    "SnapshotNumOps" : 0,
    "SnapshotAvgTime" : 0.0,
    "PublishNumOps" : 0,
    "PublishAvgTime" : 0.0,
    "DroppedPubAll" : 0
  }, {
    "name" : "Hadoop:service=DataNode,name=UgiMetrics",
    "modelerType" : "UgiMetrics",
    "tag.Context" : "ugi",
    "tag.Hostname" : "c0814.hal.cloudera.com",
    "LoginSuccessNumOps" : 0,
    "LoginSuccessAvgTime" : 0.0,
    "LoginFailureNumOps" : 0,
    "LoginFailureAvgTime" : 0.0
  }, {
    "name" : "java.lang:type=MemoryPool,name=Code Cache",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "Code Cache",
    "Type" : "NON_HEAP",
    "Valid" : true,
    "CollectionUsage" : null,
    "MemoryManagerNames" : [ "CodeCacheManager" ],
    "PeakUsage" : {
      "committed" : 5308416,
      "init" : 2555904,
      "max" : 50331648,
      "used" : 5171456
    },
    "Usage" : {
      "committed" : 5308416,
      "init" : 2555904,
      "max" : 50331648,
      "used" : 4942784
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdSupported" : false,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "java.lang:type=Runtime",
    "modelerType" : "sun.management.RuntimeImpl",
    "Name" : "22442@c0814.hal.cloudera.com",
    "ClassPath" : "/var/run/cloudera-scm-agent/process/50146-hdfs-DATANODE:/usr/lib/hadoop/lib/jetty-util-6.1.26.cloudera.2.jar:/usr/lib/hadoop/lib/jersey-server-1.8.jar:/usr/lib/hadoop/lib/jetty-6.1.26.cloudera.2.jar:/usr/lib/hadoop/lib/jline-0.9.94.jar:/usr/lib/hadoop/lib/commons-net-3.1.jar:/usr/lib/hadoop/lib/jettison-1.1.jar:/usr/lib/hadoop/lib/jets3t-0.6.1.jar:/usr/lib/hadoop/lib/commons-configuration-1.6.jar:/usr/lib/hadoop/lib/avro-1.7.1.cloudera.2.jar:/usr/lib/hadoop/lib/junit-4.8.2.jar:/usr/lib/hadoop/lib/commons-collections-3.2.1.jar:/usr/lib/hadoop/lib/stax-api-1.0.1.jar:/usr/lib/hadoop/lib/asm-3.2.jar:/usr/lib/hadoop/lib/activation-1.1.jar:/usr/lib/hadoop/lib/mockito-all-1.8.5.jar:/usr/lib/hadoop/lib/commons-beanutils-core-1.8.0.jar:/usr/lib/hadoop/lib/paranamer-2.3.jar:/usr/lib/hadoop/lib/servlet-api-2.5.jar:/usr/lib/hadoop/lib/commons-io-2.1.jar:/usr/lib/hadoop/lib/jasper-runtime-5.5.23.jar:/usr/lib/hadoop/lib/jaxb-impl-2.2.3-1.jar:/usr/lib/hadoop/lib/jsr305-1.3.9.jar:/usr/lib/hadoop/lib/hue-plugins-2.1.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop/lib/commons-lang-2.5.jar:/usr/lib/hadoop/lib/guava-11.0.2.jar:/usr/lib/hadoop/lib/jersey-core-1.8.jar:/usr/lib/hadoop/lib/commons-cli-1.2.jar:/usr/lib/hadoop/lib/jsch-0.1.42.jar:/usr/lib/hadoop/lib/jersey-json-1.8.jar:/usr/lib/hadoop/lib/commons-math-2.1.jar:/usr/lib/hadoop/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop/lib/slf4j-log4j12-1.6.1.jar:/usr/lib/hadoop/lib/jackson-xc-1.8.8.jar:/usr/lib/hadoop/lib/snappy-java-1.0.4.1.jar:/usr/lib/hadoop/lib/jaxb-api-2.2.2.jar:/usr/lib/hadoop/lib/commons-httpclient-3.1.jar:/usr/lib/hadoop/lib/commons-beanutils-1.7.0.jar:/usr/lib/hadoop/lib/commons-el-1.0.jar:/usr/lib/hadoop/lib/slf4j-api-1.6.1.jar:/usr/lib/hadoop/lib/commons-digester-1.8.jar:/usr/lib/hadoop/lib/log4j-1.2.17.jar:/usr/lib/hadoop/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop/lib/jackson-jaxrs-1.8.8.jar:/usr/lib/hadoop/lib/commons-logging-1.1.1.jar:/usr/lib/hadoop/lib/zookeeper-3.4.3-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/lib/kfs-0.3.jar:/usr/lib/hadoop/lib/jsp-api-2.1.jar:/usr/lib/hadoop/lib/commons-codec-1.4.jar:/usr/lib/hadoop/lib/xmlenc-0.52.jar:/usr/lib/hadoop/lib/jasper-compiler-5.5.23.jar:/usr/lib/hadoop/.//hadoop-auth-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/.//hadoop-common-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop/.//hadoop-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/.//hadoop-annotations-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/.//hadoop-auth.jar:/usr/lib/hadoop/.//hadoop-annotations.jar:/usr/lib/hadoop/.//hadoop-common.jar:/usr/share/cmf/lib/plugins/event-publish-4.1.0-SNAPSHOT-shaded.jar:/usr/lib/hadoop-hdfs/./:/usr/lib/hadoop-hdfs/lib/commons-daemon-1.0.3.jar:/usr/lib/hadoop-hdfs/lib/jetty-util-6.1.26.cloudera.2.jar:/usr/lib/hadoop-hdfs/lib/jersey-server-1.8.jar:/usr/lib/hadoop-hdfs/lib/jetty-6.1.26.cloudera.2.jar:/usr/lib/hadoop-hdfs/lib/jline-0.9.94.jar:/usr/lib/hadoop-hdfs/lib/asm-3.2.jar:/usr/lib/hadoop-hdfs/lib/servlet-api-2.5.jar:/usr/lib/hadoop-hdfs/lib/commons-io-2.1.jar:/usr/lib/hadoop-hdfs/lib/jasper-runtime-5.5.23.jar:/usr/lib/hadoop-hdfs/lib/jsr305-1.3.9.jar:/usr/lib/hadoop-hdfs/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop-hdfs/lib/commons-lang-2.5.jar:/usr/lib/hadoop-hdfs/lib/guava-11.0.2.jar:/usr/lib/hadoop-hdfs/lib/jersey-core-1.8.jar:/usr/lib/hadoop-hdfs/lib/commons-cli-1.2.jar:/usr/lib/hadoop-hdfs/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop-hdfs/lib/commons-el-1.0.jar:/usr/lib/hadoop-hdfs/lib/log4j-1.2.17.jar:/usr/lib/hadoop-hdfs/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop-hdfs/lib/commons-logging-1.1.1.jar:/usr/lib/hadoop-hdfs/lib/zookeeper-3.4.3-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-hdfs/lib/jsp-api-2.1.jar:/usr/lib/hadoop-hdfs/lib/commons-codec-1.4.jar:/usr/lib/hadoop-hdfs/lib/xmlenc-0.52.jar:/usr/lib/hadoop-hdfs/.//hadoop-hdfs-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop-hdfs/.//hadoop-hdfs-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-hdfs/.//hadoop-hdfs.jar:/usr/lib/hadoop-yarn/lib/jersey-server-1.8.jar:/usr/lib/hadoop-yarn/lib/guice-servlet-3.0.jar:/usr/lib/hadoop-yarn/lib/avro-1.7.1.cloudera.2.jar:/usr/lib/hadoop-yarn/lib/aopalliance-1.0.jar:/usr/lib/hadoop-yarn/lib/asm-3.2.jar:/usr/lib/hadoop-yarn/lib/guice-3.0.jar:/usr/lib/hadoop-yarn/lib/paranamer-2.3.jar:/usr/lib/hadoop-yarn/lib/commons-io-2.1.jar:/usr/lib/hadoop-yarn/lib/netty-3.2.4.Final.jar:/usr/lib/hadoop-yarn/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop-yarn/lib/jersey-core-1.8.jar:/usr/lib/hadoop-yarn/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop-yarn/lib/snappy-java-1.0.4.1.jar:/usr/lib/hadoop-yarn/lib/log4j-1.2.17.jar:/usr/lib/hadoop-yarn/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop-yarn/lib/jersey-guice-1.8.jar:/usr/lib/hadoop-yarn/lib/javax.inject-1.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-common.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-resourcemanager-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-web-proxy-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-tests-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-nodemanager-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-resourcemanager.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-applications-distributedshell-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-common.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-web-proxy.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-site-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-nodemanager.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-tests-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-applications-distributedshell.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-api-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-tests.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-api.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-site.jar:/usr/lib/hadoop-mapreduce/lib/jersey-server-1.8.jar:/usr/lib/hadoop-mapreduce/lib/guice-servlet-3.0.jar:/usr/lib/hadoop-mapreduce/lib/avro-1.7.1.cloudera.2.jar:/usr/lib/hadoop-mapreduce/lib/aopalliance-1.0.jar:/usr/lib/hadoop-mapreduce/lib/asm-3.2.jar:/usr/lib/hadoop-mapreduce/lib/guice-3.0.jar:/usr/lib/hadoop-mapreduce/lib/paranamer-2.3.jar:/usr/lib/hadoop-mapreduce/lib/commons-io-2.1.jar:/usr/lib/hadoop-mapreduce/lib/netty-3.2.4.Final.jar:/usr/lib/hadoop-mapreduce/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop-mapreduce/lib/jersey-core-1.8.jar:/usr/lib/hadoop-mapreduce/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop-mapreduce/lib/snappy-java-1.0.4.1.jar:/usr/lib/hadoop-mapreduce/lib/log4j-1.2.17.jar:/usr/lib/hadoop-mapreduce/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop-mapreduce/lib/jersey-guice-1.8.jar:/usr/lib/hadoop-mapreduce/lib/javax.inject-1.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-jobclient-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-app-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-distcp.jar:/usr/lib/hadoop-mapreduce/.//hadoop-streaming.jar:/usr/lib/hadoop-mapreduce/.//hadoop-gridmix-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-streaming-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-rumen-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-core.jar:/usr/lib/hadoop-mapreduce/.//hadoop-archives.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-examples.jar:/usr/lib/hadoop-mapreduce/.//hadoop-datajoin.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-shuffle.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-common.jar:/usr/lib/hadoop-mapreduce/.//hadoop-extras-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-rumen.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-jobclient-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-app.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-core-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-shuffle-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-distcp-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-hs.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-jobclient.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-hs-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-extras.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-examples-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-archives-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-gridmix.jar:/usr/lib/hadoop-mapreduce/.//hadoop-datajoin-2.0.0-cdh4.1.1-SNAPSHOT.jar",
    "StartTime" : 1350410710397,
    "BootClassPath" : "/usr/java/jdk1.6.0_31/jre/lib/resources.jar:/usr/java/jdk1.6.0_31/jre/lib/rt.jar:/usr/java/jdk1.6.0_31/jre/lib/sunrsasign.jar:/usr/java/jdk1.6.0_31/jre/lib/jsse.jar:/usr/java/jdk1.6.0_31/jre/lib/jce.jar:/usr/java/jdk1.6.0_31/jre/lib/charsets.jar:/usr/java/jdk1.6.0_31/jre/lib/modules/jdk.boot.jar:/usr/java/jdk1.6.0_31/jre/classes",
    "LibraryPath" : "/usr/lib/hadoop/lib/native",
    "VmName" : "Java HotSpot(TM) 64-Bit Server VM",
    "VmVendor" : "Sun Microsystems Inc.",
    "VmVersion" : "20.6-b01",
    "BootClassPathSupported" : true,
    "InputArguments" : [ "-Dproc_datanode", "-Xmx1000m", "-Dhdfs.audit.logger=INFO,RFAAUDIT", "-Dsecurity.audit.logger=INFO,RFAS", "-Djava.net.preferIPv4Stack=true", "-Dhadoop.log.dir=/var/log/hadoop-hdfs", "-Dhadoop.log.file=hadoop-cmf-hdfs1-DATANODE-c0814.hal.cloudera.com.log.out", "-Dhadoop.home.dir=/usr/lib/hadoop", "-Dhadoop.id.str=hdfs", "-Dhadoop.root.logger=INFO,RFA", "-Djava.library.path=/usr/lib/hadoop/lib/native", "-Dhadoop.policy.file=hadoop-policy.xml", "-Djava.net.preferIPv4Stack=true", "-Xmx1073741824", "-Dhadoop.security.logger=INFO,RFAS" ],
    "ManagementSpecVersion" : "1.2",
    "SpecName" : "Java Virtual Machine Specification",
    "SpecVendor" : "Sun Microsystems Inc.",
    "SpecVersion" : "1.0",
    "SystemProperties" : [ {
      "key" : "proc_datanode",
      "value" : ""
    }, {
      "key" : "security.audit.logger",
      "value" : "INFO,RFAS"
    }, {
      "key" : "java.ext.dirs",
      "value" : "/usr/java/jdk1.6.0_31/jre/lib/ext:/usr/java/packages/lib/ext"
    }, {
      "key" : "hadoop.home.dir",
      "value" : "/usr/lib/hadoop"
    }, {
      "key" : "java.vm.specification.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "user.timezone",
      "value" : "US/Pacific"
    }, {
      "key" : "hadoop.id.str",
      "value" : "hdfs"
    }, {
      "key" : "java.vm.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "user.name",
      "value" : "hdfs"
    }, {
      "key" : "java.vm.specification.name",
      "value" : "Java Virtual Machine Specification"
    }, {
      "key" : "user.dir",
      "value" : "/var/run/cloudera-scm-agent/process/50146-hdfs-DATANODE"
    }, {
      "key" : "user.country",
      "value" : "US"
    }, {
      "key" : "user.language",
      "value" : "en"
    }, {
      "key" : "java.specification.version",
      "value" : "1.6"
    }, {
      "key" : "hadoop.log.file",
      "value" : "hadoop-cmf-hdfs1-DATANODE-c0814.hal.cloudera.com.log.out"
    }, {
      "key" : "hadoop.policy.file",
      "value" : "hadoop-policy.xml"
    }, {
      "key" : "sun.cpu.endian",
      "value" : "little"
    }, {
      "key" : "java.home",
      "value" : "/usr/java/jdk1.6.0_31/jre"
    }, {
      "key" : "java.net.preferIPv4Stack",
      "value" : "true"
    }, {
      "key" : "sun.jnu.encoding",
      "value" : "UTF-8"
    }, {
      "key" : "file.separator",
      "value" : "/"
    }, {
      "key" : "java.vendor.url",
      "value" : "http://java.sun.com/"
    }, {
      "key" : "java.awt.graphicsenv",
      "value" : "sun.awt.X11GraphicsEnvironment"
    }, {
      "key" : "hadoop.log.dir",
      "value" : "/var/log/hadoop-hdfs"
    }, {
      "key" : "os.arch",
      "value" : "amd64"
    }, {
      "key" : "java.io.tmpdir",
      "value" : "/tmp"
    }, {
      "key" : "java.runtime.name",
      "value" : "Java(TM) SE Runtime Environment"
    }, {
      "key" : "java.awt.printerjob",
      "value" : "sun.print.PSPrinterJob"
    }, {
      "key" : "file.encoding",
      "value" : "UTF-8"
    }, {
      "key" : "java.version",
      "value" : "1.6.0_31"
    }, {
      "key" : "java.vendor.url.bug",
      "value" : "http://java.sun.com/cgi-bin/bugreport.cgi"
    }, {
      "key" : "java.vm.specification.version",
      "value" : "1.0"
    }, {
      "key" : "file.encoding.pkg",
      "value" : "sun.io"
    }, {
      "key" : "sun.java.command",
      "value" : "org.apache.hadoop.hdfs.server.datanode.DataNode"
    }, {
      "key" : "sun.java.launcher",
      "value" : "SUN_STANDARD"
    }, {
      "key" : "path.separator",
      "value" : ":"
    }, {
      "key" : "java.runtime.version",
      "value" : "1.6.0_31-b04"
    }, {
      "key" : "java.class.path",
      "value" : "/var/run/cloudera-scm-agent/process/50146-hdfs-DATANODE:/usr/lib/hadoop/lib/jetty-util-6.1.26.cloudera.2.jar:/usr/lib/hadoop/lib/jersey-server-1.8.jar:/usr/lib/hadoop/lib/jetty-6.1.26.cloudera.2.jar:/usr/lib/hadoop/lib/jline-0.9.94.jar:/usr/lib/hadoop/lib/commons-net-3.1.jar:/usr/lib/hadoop/lib/jettison-1.1.jar:/usr/lib/hadoop/lib/jets3t-0.6.1.jar:/usr/lib/hadoop/lib/commons-configuration-1.6.jar:/usr/lib/hadoop/lib/avro-1.7.1.cloudera.2.jar:/usr/lib/hadoop/lib/junit-4.8.2.jar:/usr/lib/hadoop/lib/commons-collections-3.2.1.jar:/usr/lib/hadoop/lib/stax-api-1.0.1.jar:/usr/lib/hadoop/lib/asm-3.2.jar:/usr/lib/hadoop/lib/activation-1.1.jar:/usr/lib/hadoop/lib/mockito-all-1.8.5.jar:/usr/lib/hadoop/lib/commons-beanutils-core-1.8.0.jar:/usr/lib/hadoop/lib/paranamer-2.3.jar:/usr/lib/hadoop/lib/servlet-api-2.5.jar:/usr/lib/hadoop/lib/commons-io-2.1.jar:/usr/lib/hadoop/lib/jasper-runtime-5.5.23.jar:/usr/lib/hadoop/lib/jaxb-impl-2.2.3-1.jar:/usr/lib/hadoop/lib/jsr305-1.3.9.jar:/usr/lib/hadoop/lib/hue-plugins-2.1.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop/lib/commons-lang-2.5.jar:/usr/lib/hadoop/lib/guava-11.0.2.jar:/usr/lib/hadoop/lib/jersey-core-1.8.jar:/usr/lib/hadoop/lib/commons-cli-1.2.jar:/usr/lib/hadoop/lib/jsch-0.1.42.jar:/usr/lib/hadoop/lib/jersey-json-1.8.jar:/usr/lib/hadoop/lib/commons-math-2.1.jar:/usr/lib/hadoop/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop/lib/slf4j-log4j12-1.6.1.jar:/usr/lib/hadoop/lib/jackson-xc-1.8.8.jar:/usr/lib/hadoop/lib/snappy-java-1.0.4.1.jar:/usr/lib/hadoop/lib/jaxb-api-2.2.2.jar:/usr/lib/hadoop/lib/commons-httpclient-3.1.jar:/usr/lib/hadoop/lib/commons-beanutils-1.7.0.jar:/usr/lib/hadoop/lib/commons-el-1.0.jar:/usr/lib/hadoop/lib/slf4j-api-1.6.1.jar:/usr/lib/hadoop/lib/commons-digester-1.8.jar:/usr/lib/hadoop/lib/log4j-1.2.17.jar:/usr/lib/hadoop/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop/lib/jackson-jaxrs-1.8.8.jar:/usr/lib/hadoop/lib/commons-logging-1.1.1.jar:/usr/lib/hadoop/lib/zookeeper-3.4.3-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/lib/kfs-0.3.jar:/usr/lib/hadoop/lib/jsp-api-2.1.jar:/usr/lib/hadoop/lib/commons-codec-1.4.jar:/usr/lib/hadoop/lib/xmlenc-0.52.jar:/usr/lib/hadoop/lib/jasper-compiler-5.5.23.jar:/usr/lib/hadoop/.//hadoop-auth-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/.//hadoop-common-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop/.//hadoop-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/.//hadoop-annotations-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/.//hadoop-auth.jar:/usr/lib/hadoop/.//hadoop-annotations.jar:/usr/lib/hadoop/.//hadoop-common.jar:/usr/share/cmf/lib/plugins/event-publish-4.1.0-SNAPSHOT-shaded.jar:/usr/lib/hadoop-hdfs/./:/usr/lib/hadoop-hdfs/lib/commons-daemon-1.0.3.jar:/usr/lib/hadoop-hdfs/lib/jetty-util-6.1.26.cloudera.2.jar:/usr/lib/hadoop-hdfs/lib/jersey-server-1.8.jar:/usr/lib/hadoop-hdfs/lib/jetty-6.1.26.cloudera.2.jar:/usr/lib/hadoop-hdfs/lib/jline-0.9.94.jar:/usr/lib/hadoop-hdfs/lib/asm-3.2.jar:/usr/lib/hadoop-hdfs/lib/servlet-api-2.5.jar:/usr/lib/hadoop-hdfs/lib/commons-io-2.1.jar:/usr/lib/hadoop-hdfs/lib/jasper-runtime-5.5.23.jar:/usr/lib/hadoop-hdfs/lib/jsr305-1.3.9.jar:/usr/lib/hadoop-hdfs/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop-hdfs/lib/commons-lang-2.5.jar:/usr/lib/hadoop-hdfs/lib/guava-11.0.2.jar:/usr/lib/hadoop-hdfs/lib/jersey-core-1.8.jar:/usr/lib/hadoop-hdfs/lib/commons-cli-1.2.jar:/usr/lib/hadoop-hdfs/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop-hdfs/lib/commons-el-1.0.jar:/usr/lib/hadoop-hdfs/lib/log4j-1.2.17.jar:/usr/lib/hadoop-hdfs/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop-hdfs/lib/commons-logging-1.1.1.jar:/usr/lib/hadoop-hdfs/lib/zookeeper-3.4.3-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-hdfs/lib/jsp-api-2.1.jar:/usr/lib/hadoop-hdfs/lib/commons-codec-1.4.jar:/usr/lib/hadoop-hdfs/lib/xmlenc-0.52.jar:/usr/lib/hadoop-hdfs/.//hadoop-hdfs-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop-hdfs/.//hadoop-hdfs-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-hdfs/.//hadoop-hdfs.jar:/usr/lib/hadoop-yarn/lib/jersey-server-1.8.jar:/usr/lib/hadoop-yarn/lib/guice-servlet-3.0.jar:/usr/lib/hadoop-yarn/lib/avro-1.7.1.cloudera.2.jar:/usr/lib/hadoop-yarn/lib/aopalliance-1.0.jar:/usr/lib/hadoop-yarn/lib/asm-3.2.jar:/usr/lib/hadoop-yarn/lib/guice-3.0.jar:/usr/lib/hadoop-yarn/lib/paranamer-2.3.jar:/usr/lib/hadoop-yarn/lib/commons-io-2.1.jar:/usr/lib/hadoop-yarn/lib/netty-3.2.4.Final.jar:/usr/lib/hadoop-yarn/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop-yarn/lib/jersey-core-1.8.jar:/usr/lib/hadoop-yarn/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop-yarn/lib/snappy-java-1.0.4.1.jar:/usr/lib/hadoop-yarn/lib/log4j-1.2.17.jar:/usr/lib/hadoop-yarn/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop-yarn/lib/jersey-guice-1.8.jar:/usr/lib/hadoop-yarn/lib/javax.inject-1.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-common.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-resourcemanager-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-web-proxy-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-tests-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-nodemanager-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-resourcemanager.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-applications-distributedshell-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-common.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-web-proxy.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-site-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-nodemanager.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-tests-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-applications-distributedshell.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-api-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-tests.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-api.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-site.jar:/usr/lib/hadoop-mapreduce/lib/jersey-server-1.8.jar:/usr/lib/hadoop-mapreduce/lib/guice-servlet-3.0.jar:/usr/lib/hadoop-mapreduce/lib/avro-1.7.1.cloudera.2.jar:/usr/lib/hadoop-mapreduce/lib/aopalliance-1.0.jar:/usr/lib/hadoop-mapreduce/lib/asm-3.2.jar:/usr/lib/hadoop-mapreduce/lib/guice-3.0.jar:/usr/lib/hadoop-mapreduce/lib/paranamer-2.3.jar:/usr/lib/hadoop-mapreduce/lib/commons-io-2.1.jar:/usr/lib/hadoop-mapreduce/lib/netty-3.2.4.Final.jar:/usr/lib/hadoop-mapreduce/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop-mapreduce/lib/jersey-core-1.8.jar:/usr/lib/hadoop-mapreduce/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop-mapreduce/lib/snappy-java-1.0.4.1.jar:/usr/lib/hadoop-mapreduce/lib/log4j-1.2.17.jar:/usr/lib/hadoop-mapreduce/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop-mapreduce/lib/jersey-guice-1.8.jar:/usr/lib/hadoop-mapreduce/lib/javax.inject-1.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-jobclient-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-app-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-distcp.jar:/usr/lib/hadoop-mapreduce/.//hadoop-streaming.jar:/usr/lib/hadoop-mapreduce/.//hadoop-gridmix-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-streaming-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-rumen-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-core.jar:/usr/lib/hadoop-mapreduce/.//hadoop-archives.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-examples.jar:/usr/lib/hadoop-mapreduce/.//hadoop-datajoin.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-shuffle.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-common.jar:/usr/lib/hadoop-mapreduce/.//hadoop-extras-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-rumen.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-jobclient-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-app.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-core-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-shuffle-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-distcp-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-hs.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-jobclient.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-hs-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-extras.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-examples-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-archives-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-gridmix.jar:/usr/lib/hadoop-mapreduce/.//hadoop-datajoin-2.0.0-cdh4.1.1-SNAPSHOT.jar"
    }, {
      "key" : "os.name",
      "value" : "Linux"
    }, {
      "key" : "hadoop.security.logger",
      "value" : "INFO,RFAS"
    }, {
      "key" : "line.separator",
      "value" : "\n"
    }, {
      "key" : "os.version",
      "value" : "2.6.32-279.el6.x86_64"
    }, {
      "key" : "sun.arch.data.model",
      "value" : "64"
    }, {
      "key" : "java.class.version",
      "value" : "50.0"
    }, {
      "key" : "sun.io.unicode.encoding",
      "value" : "UnicodeLittle"
    }, {
      "key" : "java.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "sun.boot.class.path",
      "value" : "/usr/java/jdk1.6.0_31/jre/lib/resources.jar:/usr/java/jdk1.6.0_31/jre/lib/rt.jar:/usr/java/jdk1.6.0_31/jre/lib/sunrsasign.jar:/usr/java/jdk1.6.0_31/jre/lib/jsse.jar:/usr/java/jdk1.6.0_31/jre/lib/jce.jar:/usr/java/jdk1.6.0_31/jre/lib/charsets.jar:/usr/java/jdk1.6.0_31/jre/lib/modules/jdk.boot.jar:/usr/java/jdk1.6.0_31/jre/classes"
    }, {
      "key" : "java.vm.info",
      "value" : "mixed mode"
    }, {
      "key" : "java.specification.name",
      "value" : "Java Platform API Specification"
    }, {
      "key" : "java.vm.name",
      "value" : "Java HotSpot(TM) 64-Bit Server VM"
    }, {
      "key" : "java.vm.version",
      "value" : "20.6-b01"
    }, {
      "key" : "sun.boot.library.path",
      "value" : "/usr/java/jdk1.6.0_31/jre/lib/amd64"
    }, {
      "key" : "hadoop.root.logger",
      "value" : "INFO,RFA"
    }, {
      "key" : "java.endorsed.dirs",
      "value" : "/usr/java/jdk1.6.0_31/jre/lib/endorsed"
    }, {
      "key" : "sun.os.patch.level",
      "value" : "unknown"
    }, {
      "key" : "sun.cpu.isalist",
      "value" : ""
    }, {
      "key" : "hdfs.audit.logger",
      "value" : "INFO,RFAAUDIT"
    }, {
      "key" : "user.home",
      "value" : "/usr/lib/hadoop-0.20"
    }, {
      "key" : "java.library.path",
      "value" : "/usr/lib/hadoop/lib/native"
    }, {
      "key" : "java.specification.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "sun.management.compiler",
      "value" : "HotSpot 64-Bit Tiered Compilers"
    } ],
    "Uptime" : 182367030
  }, {
    "name" : "java.lang:type=ClassLoading",
    "modelerType" : "sun.management.ClassLoadingImpl",
    "LoadedClassCount" : 4119,
    "UnloadedClassCount" : 3,
    "TotalLoadedClassCount" : 4122,
    "Verbose" : false
  }, {
    "name" : "Hadoop:service=DataNode,name=DataNodeInfo",
    "modelerType" : "org.apache.hadoop.hdfs.server.datanode.DataNode",
    "XceiverCount" : 7,
    "Version" : "2.0.0-cdh4.1.1-SNAPSHOT",
    "RpcPort" : "50020",
    "HttpPort" : null,
    "NamenodeAddresses" : "{\"c0808.hal.cloudera.com\":\"BP-1512640679-172.29.97.199-1347408252983\",\"c1113.hal.cloudera.com\":\"BP-1507505631-172.29.97.196-1337120439433\",\"c0805.hal.cloudera.com\":\"BP-1507505631-172.29.97.196-1337120439433\"}",
    "VolumeInfo" : "{\"/data/5/dfs/dn/current\":{\"freeSpace\":333182791680,\"usedSpace\":655972937728,\"reservedSpace\":10737418240},\"/data/4/dfs/dn/current\":{\"freeSpace\":313827192832,\"usedSpace\":653880947764,\"reservedSpace\":10737418240},\"/data/3/dfs/dn/current\":{\"freeSpace\":326404517888,\"usedSpace\":662751211520,\"reservedSpace\":10737418240},\"/data/6/dfs/dn/current\":{\"freeSpace\":323973312512,\"usedSpace\":665182416896,\"reservedSpace\":10737418240},\"/data/1/dfs/dn/current\":{\"freeSpace\":79235939924,\"usedSpace\":663112434092,\"reservedSpace\":10737418240},\"/data/2/dfs/dn/current\":{\"freeSpace\":326737178624,\"usedSpace\":662418550784,\"reservedSpace\":10737418240}}",
    "ClusterId" : "cluster24"
  }, {
    "name" : "java.lang:type=Threading",
    "modelerType" : "sun.management.ThreadImpl",
    "ThreadAllocatedMemoryEnabled" : true,
    "ThreadAllocatedMemorySupported" : true,
    "ThreadContentionMonitoringEnabled" : false,
    "AllThreadIds" : [ 208143, 208141, 208138, 208137, 208136, 208134, 207661, 207660, 205687, 205686, 205685, 203466, 180286, 19406, 1014, 200, 145, 144, 143, 142, 141, 138, 135, 132, 129, 126, 99, 96, 93, 90, 87, 84, 81, 78, 50, 49, 48, 42, 44, 37, 47, 46, 45, 43, 41, 40, 36, 11, 9, 4, 3, 2, 1 ],
    "DaemonThreadCount" : 48,
    "PeakThreadCount" : 193,
    "CurrentThreadCpuTimeSupported" : true,
    "ObjectMonitorUsageSupported" : true,
    "SynchronizerUsageSupported" : true,
    "ThreadContentionMonitoringSupported" : true,
    "ThreadCpuTimeEnabled" : true,
    "CurrentThreadCpuTime" : 2880000000,
    "CurrentThreadUserTime" : 2560000000,
    "ThreadCount" : 53,
    "TotalStartedThreadCount" : 208135,
    "ThreadCpuTimeSupported" : true
  }, {
    "name" : "Hadoop:service=DataNode,name=RpcDetailedActivityForPort50020",
    "modelerType" : "RpcDetailedActivityForPort50020",
    "tag.port" : "50020",
    "tag.Context" : "rpcdetailed",
    "tag.Hostname" : "c0814.hal.cloudera.com"
  }, {
    "name" : "java.util.logging:type=Logging",
    "modelerType" : "java.util.logging.Logging",
    "LoggerNames" : [ "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.DefaultChannelPipeline", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.socket.nio.NioProviderMetadata", "global", "sun.awt.AppContext", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.CompleteChannelFuture", "com.cloudera.cmf.event.shaded.org.jboss.netty.util.ThreadRenamingRunnable", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.socket.nio.NioClientSocketChannel", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.socket.nio.NioWorker", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.socket.nio.SelectorUtil", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.SimpleChannelUpstreamHandler", "javax.management", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.socket.nio.NioClientSocketPipelineSink", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.socket.nio.DefaultNioSocketChannelConfig", "javax.management.mbeanserver", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.DefaultChannelFuture", "" ]
  }, {
    "name" : "Hadoop:service=DataNode,name=JvmMetrics",
    "modelerType" : "JvmMetrics",
    "tag.Context" : "jvm",
    "tag.ProcessName" : "DataNode",
    "tag.SessionId" : null,
    "tag.Hostname" : "c0814.hal.cloudera.com",
    "MemNonHeapUsedM" : 39.394653,
    "MemNonHeapCommittedM" : 39.75,
    "MemHeapUsedM" : 51.556923,
    "MemHeapCommittedM" : 172.5,
    "GcCount" : 82938,
    "GcTimeMillis" : 214854,
    "ThreadsNew" : 0,
    "ThreadsRunnable" : 13,
    "ThreadsBlocked" : 0,
    "ThreadsWaiting" : 15,
    "ThreadsTimedWaiting" : 25,
    "ThreadsTerminated" : 0,
    "LogFatal" : 0,
    "LogError" : 17,
    "LogWarn" : 626,
    "LogInfo" : 13665658
  }, {
    "name" : "com.sun.management:type=HotSpotDiagnostic",
    "modelerType" : "sun.management.HotSpotDiagnostic",
    "DiagnosticOptions" : [ {
      "name" : "HeapDumpBeforeFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpAfterFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpOnOutOfMemoryError",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpPath",
      "origin" : "DEFAULT",
      "value" : "",
      "writeable" : true
    }, {
      "name" : "CMSAbortablePrecleanWaitMillis",
      "origin" : "DEFAULT",
      "value" : "100",
      "writeable" : true
    }, {
      "name" : "CMSWaitDuration",
      "origin" : "DEFAULT",
      "value" : "2000",
      "writeable" : true
    }, {
      "name" : "PrintGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCDetails",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCDateStamps",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCTimeStamps",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogramBeforeFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogramAfterFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogram",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintConcurrentLocks",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    } ]
  }, {
    "name" : "java.lang:type=MemoryPool,name=PS Perm Gen",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Perm Gen",
    "Type" : "NON_HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 34209792,
      "init" : 21757952,
      "max" : 85983232,
      "used" : 33860832
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep" ],
    "PeakUsage" : {
      "committed" : 69402624,
      "init" : 21757952,
      "max" : 85983232,
      "used" : 36365504
    },
    "Usage" : {
      "committed" : 36372480,
      "init" : 21757952,
      "max" : 85983232,
      "used" : 36365504
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "Hadoop:service=DataNode,name=MetricsSystem,sub=Control",
    "modelerType" : "org.apache.hadoop.metrics2.impl.MetricsSystemImpl"
  }, {
    "name" : "java.lang:type=GarbageCollector,name=PS Scavenge",
    "modelerType" : "sun.management.GarbageCollectorImpl",
    "LastGcInfo" : {
      "GcThreadCount" : 13,
      "duration" : 7,
      "endTime" : 182364779,
      "id" : 82841,
      "memoryUsageAfterGc" : [ {
        "key" : "PS Survivor Space",
        "value" : {
          "committed" : 1441792,
          "init" : 32899072,
          "max" : 1441792,
          "used" : 1212416
        }
      }, {
        "key" : "PS Old Gen",
        "value" : {
          "committed" : 65339392,
          "init" : 527171584,
          "max" : 715849728,
          "used" : 45364592
        }
      }, {
        "key" : "PS Perm Gen",
        "value" : {
          "committed" : 36372480,
          "init" : 21757952,
          "max" : 85983232,
          "used" : 36365440
        }
      }, {
        "key" : "Code Cache",
        "value" : {
          "committed" : 5308416,
          "init" : 2555904,
          "max" : 50331648,
          "used" : 4942784
        }
      }, {
        "key" : "PS Eden Space",
        "value" : {
          "committed" : 114098176,
          "init" : 197722112,
          "max" : 355008512,
          "used" : 0
        }
      } ],
      "memoryUsageBeforeGc" : [ {
        "key" : "PS Survivor Space",
        "value" : {
          "committed" : 1441792,
          "init" : 32899072,
          "max" : 1441792,
          "used" : 1245184
        }
      }, {
        "key" : "PS Old Gen",
        "value" : {
          "committed" : 65339392,
          "init" : 527171584,
          "max" : 715849728,
          "used" : 45364592
        }
      }, {
        "key" : "PS Perm Gen",
        "value" : {
          "committed" : 36372480,
          "init" : 21757952,
          "max" : 85983232,
          "used" : 36365440
        }
      }, {
        "key" : "Code Cache",
        "value" : {
          "committed" : 5308416,
          "init" : 2555904,
          "max" : 50331648,
          "used" : 4942784
        }
      }, {
        "key" : "PS Eden Space",
        "value" : {
          "committed" : 114098176,
          "init" : 197722112,
          "max" : 355008512,
          "used" : 114098176
        }
      } ],
      "startTime" : 182364772
    },
    "CollectionCount" : 82841,
    "CollectionTime" : 196919,
    "Name" : "PS Scavenge",
    "Valid" : true,
    "MemoryPoolNames" : [ "PS Eden Space", "PS Survivor Space" ]
  }, {
    "name" : "java.lang:type=MemoryPool,name=PS Old Gen",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Old Gen",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 65339392,
      "init" : 527171584,
      "max" : 715849728,
      "used" : 32831672
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep" ],
    "PeakUsage" : {
      "committed" : 527171584,
      "init" : 527171584,
      "max" : 715849728,
      "used" : 526939072
    },
    "Usage" : {
      "committed" : 65339392,
      "init" : 527171584,
      "max" : 715849728,
      "used" : 45364592
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "JMImplementation:type=MBeanServerDelegate",
    "modelerType" : "javax.management.MBeanServerDelegate",
    "MBeanServerId" : "c0814.hal.cloudera.com_1350410711871",
    "SpecificationName" : "Java Management Extensions",
    "SpecificationVersion" : "1.4",
    "SpecificationVendor" : "Sun Microsystems",
    "ImplementationName" : "JMX",
    "ImplementationVersion" : "1.6.0_31-b04",
    "ImplementationVendor" : "Sun Microsystems"
  } ]
}
"""
