# Copyright (c) 2011 Cloudera, Inc. All rights reserved.

class JsonParser(object):
  def __init__(self, json_dict, version):
    """
    May raise ParseError if the json structure is not what
    we expect.
    """
    self.json = json_dict

# Collected from bolt CDH3 JT on 10/18/2012.
SAMPLE_CDH3 = r"""
{
   "fairscheduler":{
      "pools":[
         [
            {
               "hostName":"centos62-25.ent.cloudera.com",
               "name":"default",
               "taskType":"REDUCE"
            },
            {
               "demand":0,
               "fairShare":0.0,
               "minShare":0,
               "runningTasks":0,
               "weight":1.0
            }
         ],
         [
            {
               "hostName":"centos62-25.ent.cloudera.com",
               "name":"default",
               "taskType":"MAP"
            },
            {
               "demand":0,
               "fairShare":0.0,
               "minShare":0,
               "runningTasks":0,
               "weight":1.0
            }
         ]
      ]
   },
   "jvm":{
      "metrics":[
         [
            {
               "hostName":"centos62-25.ent.cloudera.com",
               "processName":"JobTracker",
               "sessionId":""
            },
            {
               "gcCount":41066,
               "gcTimeMillis":70942,
               "logError":0,
               "logFatal":0,
               "logInfo":83,
               "logWarn":0,
               "maxMemoryM":270.25,
               "memHeapCommittedM":6.8125,
               "memHeapUsedM":4.6171417,
               "memNonHeapCommittedM":25.9375,
               "memNonHeapUsedM":25.541763,
               "threadsBlocked":0,
               "threadsNew":0,
               "threadsRunnable":8,
               "threadsTerminated":0,
               "threadsTimedWaiting":14,
               "threadsWaiting":34
            }
         ]
      ]
   },
   "mapred":{
      "jobtracker":[
         [
            {
               "hostName":"centos62-25.ent.cloudera.com",
               "sessionId":""
            },
            {
               "blacklisted_maps":0,
               "blacklisted_reduces":0,
               "heartbeats":10538152,
               "jobs_completed":0,
               "jobs_failed":0,
               "jobs_killed":0,
               "jobs_preparing":0,
               "jobs_running":0,
               "jobs_submitted":0,
               "map_slots":8,
               "maps_completed":0,
               "maps_failed":0,
               "maps_killed":0,
               "maps_launched":0,
               "occupied_map_slots":0,
               "occupied_reduce_slots":0,
               "reduce_slots":4,
               "reduces_completed":0,
               "reduces_failed":0,
               "reduces_killed":0,
               "reduces_launched":0,
               "reserved_map_slots":0,
               "reserved_reduce_slots":0,
               "running_maps":0,
               "running_reduces":0,
               "trackers":4,
               "trackers_blacklisted":0,
               "trackers_decommissioned":0,
               "waiting_maps":0,
               "waiting_reduces":0
            }
         ]
      ]
   },
   "rpc":{
      "detailed-metrics":[
         [
            {
               "hostName":"centos62-25.ent.cloudera.com",
               "port":"8021"
            },
            {
               "getBuildVersion_avg_time":0,
               "getBuildVersion_num_ops":4,
               "getClusterStatus_avg_time":0,
               "getClusterStatus_num_ops":13260,
               "getProtocolVersion_avg_time":0,
               "getProtocolVersion_num_ops":13264,
               "getSystemDir_avg_time":0,
               "getSystemDir_num_ops":4,
               "getVIVersion_avg_time":0,
               "getVIVersion_num_ops":4,
               "heartbeat_avg_time":0,
               "heartbeat_num_ops":10538132,
               "jobsToComplete_avg_time":0,
               "jobsToComplete_num_ops":13260
            }
         ]
      ],
      "metrics":[
         [
            {
               "hostName":"centos62-25.ent.cloudera.com",
               "port":"8021"
            },
            {
               "NumOpenConnections":4,
               "ReceivedBytes":3370215986,
               "RpcProcessingTime_avg_time":0,
               "RpcProcessingTime_num_ops":10577928,
               "RpcQueueTime_avg_time":0,
               "RpcQueueTime_num_ops":10577928,
               "SentBytes":1133959356,
               "callQueueLen":0,
               "rpcAuthenticationFailures":0,
               "rpcAuthenticationSuccesses":0,
               "rpcAuthorizationFailures":0,
               "rpcAuthorizationSuccesses":13264
            }
         ]
      ]
   },
   "ugi":{
      "ugi":[
         [
            {
               "hostName":"centos62-25.ent.cloudera.com"
            },
            {
               "loginFailure_avg_time":0,
               "loginFailure_num_ops":0,
               "loginSuccess_avg_time":0,
               "loginSuccess_num_ops":0
            }
         ]
      ]
   }
}
"""

# Collected from bolt CDH4 JT on 10/18/2012.
SAMPLE_CDH4 = r"""
{
   "fairscheduler":{
      "jobs":[
         [
            {
               "hostName":"c0804.hal.cloudera.com",
               "name":"job_201210161107_1305",
               "taskType":"REDUCE"
            },
            {
               "demand":0,
               "fairShare":0.0,
               "minShare":0,
               "runningTasks":0,
               "weight":1.0
            }
         ],
         [
            {
               "hostName":"c0804.hal.cloudera.com",
               "name":"job_201210161107_1305",
               "taskType":"MAP"
            },
            {
               "demand":163,
               "fairShare":163.0,
               "minShare":0,
               "runningTasks":162,
               "weight":1.0
            }
         ]
      ],
      "pools":[
         [
            {
               "hostName":"c0804.hal.cloudera.com",
               "name":"hudson",
               "taskType":"REDUCE"
            },
            {
               "demand":0,
               "fairShare":0.0,
               "minShare":0,
               "runningTasks":0,
               "weight":1.0
            }
         ],
         [
            {
               "hostName":"c0804.hal.cloudera.com",
               "name":"default",
               "taskType":"REDUCE"
            },
            {
               "demand":0,
               "fairShare":0.0,
               "minShare":0,
               "runningTasks":0,
               "weight":1.0
            }
         ],
         [
            {
               "hostName":"c0804.hal.cloudera.com",
               "name":"mj",
               "taskType":"REDUCE"
            },
            {
               "demand":0,
               "fairShare":0.0,
               "minShare":0,
               "runningTasks":0,
               "weight":1.0
            }
         ],
         [
            {
               "hostName":"c0804.hal.cloudera.com",
               "name":"philip",
               "taskType":"REDUCE"
            },
            {
               "demand":0,
               "fairShare":0.0,
               "minShare":0,
               "runningTasks":0,
               "weight":1.0
            }
         ],
         [
            {
               "hostName":"c0804.hal.cloudera.com",
               "name":"mj",
               "taskType":"MAP"
            },
            {
               "demand":0,
               "fairShare":0.0,
               "minShare":0,
               "runningTasks":0,
               "weight":1.0
            }
         ],
         [
            {
               "hostName":"c0804.hal.cloudera.com",
               "name":"philip",
               "taskType":"MAP"
            },
            {
               "demand":0,
               "fairShare":0.0,
               "minShare":0,
               "runningTasks":0,
               "weight":1.0
            }
         ],
         [
            {
               "hostName":"c0804.hal.cloudera.com",
               "name":"hudson",
               "taskType":"MAP"
            },
            {
               "demand":163,
               "fairShare":163.0,
               "minShare":0,
               "runningTasks":162,
               "weight":1.0
            }
         ],
         [
            {
               "hostName":"c0804.hal.cloudera.com",
               "name":"default",
               "taskType":"MAP"
            },
            {
               "demand":0,
               "fairShare":0.0,
               "minShare":0,
               "runningTasks":0,
               "weight":1.0
            }
         ]
      ]
   },
   "jvm":{
      "metrics":[
         [
            {
               "hostName":"c0804.hal.cloudera.com",
               "processName":"JobTracker",
               "sessionId":""
            },
            {
               "gcCount":62457,
               "gcTimeMillis":392153,
               "logError":0,
               "logFatal":0,
               "logInfo":2254586,
               "logWarn":418730,
               "maxMemoryM":9738.6875,
               "memHeapCommittedM":445.6875,
               "memHeapUsedM":375.99985,
               "memNonHeapCommittedM":47.625,
               "memNonHeapUsedM":47.396835,
               "threadsBlocked":0,
               "threadsNew":0,
               "threadsRunnable":10,
               "threadsTerminated":0,
               "threadsTimedWaiting":13,
               "threadsWaiting":28
            }
         ]
      ]
   },
   "mapred":{
      "job":[

      ],
      "jobtracker":[
         [
            {
               "hostName":"c0804.hal.cloudera.com",
               "sessionId":""
            },
            {
               "blacklisted_maps":0,
               "blacklisted_reduces":0,
               "heartbeats":17879043,
               "jobs_completed":1303,
               "jobs_failed":0,
               "jobs_killed":1,
               "jobs_preparing":0,
               "jobs_running":1,
               "jobs_submitted":1305,
               "map_slots":1424,
               "maps_completed":346800,
               "maps_failed":45,
               "maps_killed":0,
               "maps_launched":347019,
               "occupied_map_slots":172,
               "occupied_reduce_slots":0,
               "reduce_slots":712,
               "reduces_completed":58264,
               "reduces_failed":5110,
               "reduces_killed":0,
               "reduces_launched":63374,
               "reserved_map_slots":0,
               "reserved_reduce_slots":0,
               "running_maps":172,
               "running_reduces":0,
               "trackers":89,
               "trackers_blacklisted":0,
               "trackers_decommissioned":0,
               "waiting_maps":0,
               "waiting_reduces":880
            }
         ]
      ]
   }
}
"""

SAMPLE = SAMPLE_CDH4
